BuildOpt

Struct BuildOpt 

pub struct BuildOpt {
    pub build_args: Vec<(String, String)>,
    pub context: PathBuf,
    pub dockerfile: Option<PathBuf>,
    pub iidfile: Option<PathBuf>,
    pub no_cache: bool,
    pub pull: bool,
    pub quiet: bool,
    pub tag: Option<String>,
}
Options for building a container.

Fields

build_args: Vec<(String, String)>

Build-time variables.

context: PathBuf

Root directory containing files that can be pulled into the container.

dockerfile: Option<PathBuf>

Dockerfile to build. This must be somewhere in the context directory. If not set (the default) then <context>/Dockerfile is used.

iidfile: Option<PathBuf>

If set, the image ID will be written to this path.

no_cache: bool

Do not use cache when building the image.

pull: bool

Always attempt to pull a newer version of the image.

quiet: bool

Suppress the build output and print image ID on success.

tag: Option<String>

If set, the image will be tagged with this name.