Launcher

Struct Launcher 

pub struct Launcher { /* private fields */ }
Base container command used for building and running containers.

This allows variations such as “docker”, “sudo docker”, and “podman”.

Implementations

Source

impl Launcher

pub fn new(base_command: Command) -> Self

Create a new Launcher with the specified base Command. The base command is used to create all the other commands.

pub fn auto() -> Option<Self>

Automatically choose a base command.

  • Chooses podman if is in the $PATH.
  • Otherwise chooses docker if it is in the $PATH.
    • If the current user is not in a docker group, sudo is added.

If neither command is in the $PATH, returns None.

pub fn is_docker(&self) -> bool

Whether the base command appears to be docker. This checks if the program or any of the arguments in the base command match “docker”.

pub fn is_podman(&self) -> bool

Whether the base command appears to be podman. This checks if the program or any of the arguments in the base command match “podman”.

pub fn base_command(&self) -> &Command

Get the base Command.

pub fn build(&self, opt: BuildOpt) -> Command

Create a Command for building a container.

pub fn create_network(&self, opt: CreateNetworkOpt) -> Command

Create a Command for creating a network.

pub fn remove_network(&self, name: &str) -> Command

Create a Command for removing a network.

pub fn run(&self, opt: RunOpt) -> Command

Create a Command for running a container.

pub fn stop(&self, opt: StopOpt) -> Command

Create a Command for stopping containers.